pub struct TextureAtlas {
pub layout: Handle<TextureAtlasLayout>,
pub index: usize,
}Expand description
An index into a TextureAtlasLayout, which corresponds to a specific section of a texture.
It stores a handle to TextureAtlasLayout and the index of the current section of the atlas.
The texture atlas contains various sections of a given texture, allowing users to have a single
image file for either sprite animation or global mapping.
You can change the texture index of the atlas to animate the sprite or display only a section of the texture
for efficient rendering of related game objects.
Check the following examples for usage:
Fields
layout: Handle<TextureAtlasLayout>Texture atlas layout handle
index: usizeTexture atlas section index
Implementations
Sourceimpl TextureAtlas
impl TextureAtlas
Sourcepub fn texture_rect(
&self,
texture_atlases: &Assets<TextureAtlasLayout>,
) -> Option<URect>
pub fn texture_rect( &self, texture_atlases: &Assets<TextureAtlasLayout>, ) -> Option<URect>
Retrieves the current texture URect of the sprite sheet according to the section index
Sourcepub fn with_index(self, index: usize) -> Self
pub fn with_index(self, index: usize) -> Self
Returns this TextureAtlas with the specified index.
Sourcepub fn with_layout(self, layout: Handle<TextureAtlasLayout>) -> Self
pub fn with_layout(self, layout: Handle<TextureAtlasLayout>) -> Self
Returns this TextureAtlas with the specified TextureAtlasLayout handle.